pub struct ConstellationCompiler;Expand description
Compiles a constellation into a bundle for a deployment target.
Implementations
Sourceimpl ConstellationCompiler
impl ConstellationCompiler
Sourcepub fn compile(
constellation: &Constellation,
target: DeploymentTarget,
) -> Result<CompiledConstellation, ResolutionError>
pub fn compile( constellation: &Constellation, target: DeploymentTarget, ) -> Result<CompiledConstellation, ResolutionError>
Compile a constellation for a given target. In a real implementation this would invoke cross-compilation toolchains. Here we simulate it with size estimates and checksum generation.